==> ukolovnik-0.5.tar.bz2: ukolovnik-0.5/languages/cz.php <==
<?php
// Uložte tento soubor jako ukolovnik/languages/cz.php, jazyk pak můžete zvolit v nastaveních

// vim: expandtab sw=4 ts=4 sts=4:

// English language file for Ukolovnik

$locale['Main'] = 'Hlavní';
$locale['Add'] = 'Přidat';
$locale['Export'] = 'Export';
$locale['Stats'] = 'Statistiky';
$locale['Settings'] = 'Nastavení';
$locale['DefaultStyle'] = 'Výchozí vzhled';
$locale['ExtensionNeeded'] = 'Nepodařilo se načíst potřebné rozšíření PHP "%s". Prosím nainstalujte a povolte ho.';
$locale['CanNotConnect'] = 'Nepodařilo se připojit k MySQL databázi. Prosím zkontrolujte vaše nastavení.';
$locale['CanNotSelectDb'] = 'Nepodařilo se vybrat zvolenou databázi. Prosím zkontrolujte vaše nastavení nebo použijte setup.php.';
$locale['CanNotFindTable'] = 'Nepodařilo se nalézt tabulku "%s". Prosím zkontrolujte vaše nastavení nebo použijte setup.php.';
$locale['UnknownCommand'] = 'Neznámý příkaz! Pravděpodobně jste narazili na neimplementovanou funkcionalitu.';
$locale['Categories'] = 'Kategorie';
$locale['AddCategory'] = 'Přidat kategorii';
$locale['EditCategory'] = 'Upravit kategorii';
$locale['NoCategories'] = 'Nejsou definovány žádné kategorie.';
$locale['NoEntries'] = 'Nebyly nalezeny žádne položky.';
$locale['Name'] = 'Jméno';
$locale['Add'] = 'Přidat';
$locale['NameNotEmpty'] = 'Jméno nesmí být prázdné.';
$locale['TitleNotEmpty'] = 'Název nesmí být prázdný.';
$locale['CategoryInvalid'] = 'Chybná kategorie.';
$locale['PriorityInvalid'] = 'Chybná priorita.';
$locale['ParameterInvalid'] = 'Chybné parametry.';
$locale['CategoryAdded'] = 'Kategorie %s byla přidána.';
$locale['TaskAdded'] = 'Úkol %s byl přidán.';
$locale['Title'] = 'Název';
$locale['Description'] = 'Popis';
$locale['Priority'] = 'Priorita';
$locale['Priority0'] = 'Nízká';
$locale['Priority1'] = 'Střední';
$locale['Priority2'] = 'Vysoká';
$locale['Category'] = 'Kategorie';
$locale['Personal'] = 'Osobní';
$locale['Show'] = 'Zobrazit';
$locale['Hide'] = 'Schovat';
$locale['All'] = 'Vše';
$locale['Filter'] = 'Filtr';
$locale['SQLFailed'] = 'Dotaz SQL selhal: %s';
$locale['InvalidLanguage'] = 'Byl zvolen chybný jazyk (%s).';
$locale['Actions'] = 'Akce';
$locale['Any'] = 'Jakýkoliv';
$locale['Text'] = 'Text';
$locale['Finished'] = 'Ukončen';
$locale['Edit'] = 'Upravit';
$locale['Delete'] = 'Smazat';
$locale['Created'] = 'Vytvořen';
$locale['Updated'] = 'Aktualizován';
$locale['Closed'] = 'Uzavřený';
$locale['Reopen'] = 'Otevřít';
$locale['Finish'] = 'Ukončit';
$locale['TaskFinished'] = 'Úkol %s byl ukončen.';
$locale['TaskReopened'] = 'Úkol %s byl otevřen.';
$locale['TaskDeleted'] = 'Úkol %s byl vymazán.';
$locale['CategoryDeleted'] = 'Kategorie %s byla vymazána.';
$locale['TaskChanged'] = 'Úkol %s byl změněn.';
$locale['CategoryChanged'] = 'Kategorie %s byla změněna.';
$locale['InvalidId']  = 'Chyné ID.';
$locale['Yes'] = 'Ano';
$locale['No'] = 'Ne';
$locale['Item'] = 'Položka';
$locale['OldestTask'] = 'Nejstarší úkol';
$locale['OldestOpenedTask'] = 'Nejstarší otevřený úkol';
$locale['TotalTaskCount'] = 'Celkem úkolů';
$locale['OpenedTaskCount'] = 'Otevřených úkolů';
$locale['OpenedTaskP0'] = 'Otevřených úkolů s nízkou prioritou';
$locale['OpenedTaskP1'] = 'Otevřených úkolů se střední prioritou';
$locale['OpenedTaskP2'] = 'Otevřených úkolů s vysokou prioritou';
$locale['AverageOpenedAge'] = 'Průměrný stáři otevřeného úkolu';
$locale['AverageCloseAge'] = 'Průměrné stáří úkolu při uzavření';
$locale['AverageAge'] = 'Průměrné stáří úkolu';
$locale['OldestOpenedTaskAge'] = 'Stáří nejdéle otevřeného úkolu';
$locale['OldestTaskAge'] = 'Stáří nejstaršího úkolu';
$locale['Days'] = 'dnů';
$locale['DeleteCategory'] = 'Chcete vymazat kategorii "%s"';
$locale['TasksInCategory'] = 'Počet úkolů v kategorii: %d';
$locale['NoTaskCategory'] = 'Nebyly nalezeny žádné úkoly v této kategorii.';
$locale['SelectDeleteTask'] = 'Co chcete udělat s úkoly ve vymazané kategorii?';
$locale['TargetCategory'] = 'Cílová kategorie';
$locale['MoveTo'] = 'Přesunout do jiné kategorie';

$locale['datefmt'] = '%d.%m.%Y, %H:%M';

$locale['DatabaseCreated'] = 'Databáze %s byla vytvořena.';
$locale['TableCreated'] = 'Tabulka %s byla vytvořena.';
$locale['TablesUpdated'] = 'Tabulky jsou v pořádku (případné úpravy jsou popsány výše), můžete se vrátit zpět na index.php.';
$locale['SettingsDbUpdated'] = 'Databáze nastavení byla aktualizována';
$locale['SettingsUpdated'] = 'Nastavení byla aktualizována';

$locale['SetLanguage'] = 'Jazyk';
$locale['SetStyle'] = 'Vzhled';
$locale['SetAddStay'] = 'Zůstat na přidávací stránce po přidání úkolu';
$locale['SetAddList'] = 'Zobrazit seznam úkolů na přidávací stránce';
$locale['Save'] = 'Uložit';
?>

==> ukolovnik-0.6.tar.bz2: ukolovnik-0.6/languages/cz.php <==
<?php
// Uložte tento soubor jako ukolovnik/languages/cz.php, jazyk pak můžete zvolit v nastaveních

// vim: expandtab sw=4 ts=4 sts=4:

// English language file for Ukolovnik

$locale['Main'] = 'Hlavní';
$locale['Add'] = 'Přidat';
$locale['Export'] = 'Export';
$locale['Stats'] = 'Statistiky';
$locale['Settings'] = 'Nastavení';
$locale['DefaultStyle'] = 'Výchozí vzhled';
$locale['ExtensionNeeded'] = 'Nepodařilo se načíst potřebné rozšíření PHP "%s". Prosím nainstalujte a povolte ho.';
$locale['CanNotConnect'] = 'Nepodařilo se připojit k MySQL databázi. Prosím zkontrolujte vaše nastavení.';
$locale['CanNotSelectDb'] = 'Nepodařilo se vybrat zvolenou databázi. Prosím zkontrolujte vaše nastavení nebo použijte setup.php.';
$locale['CanNotFindTable'] = 'Nepodařilo se nalézt tabulku "%s". Prosím zkontrolujte vaše nastavení nebo použijte setup.php.';
$locale['UnknownCommand'] = 'Neznámý příkaz! Pravděpodobně jste narazili na neimplementovanou funkcionalitu.';
$locale['Categories'] = 'Kategorie';
$locale['AddCategory'] = 'Přidat kategorii';
$locale['EditCategory'] = 'Upravit kategorii';
$locale['NoCategories'] = 'Nejsou definovány žádné kategorie.';
$locale['NoEntries'] = 'Nebyly nalezeny žádne položky.';
$locale['Name'] = 'Jméno';
$locale['Add'] = 'Přidat';
$locale['NameNotEmpty'] = 'Jméno nesmí být prázdné.';
$locale['TitleNotEmpty'] = 'Název nesmí být prázdný.';
$locale['CategoryInvalid'] = 'Chybná kategorie.';
$locale['PriorityInvalid'] = 'Chybná priorita.';
$locale['ParameterInvalid'] = 'Chybné parametry.';
$locale['CategoryAdded'] = 'Kategorie %s byla přidána.';
$locale['TaskAdded'] = 'Úkol %s byl přidán.';
$locale['Title'] = 'Název';
$locale['Description'] = 'Popis';
$locale['Priority'] = 'Priorita';
$locale['Priority0'] = 'Nízká';
$locale['Priority1'] = 'Střední';
$locale['Priority2'] = 'Vysoká';
$locale['Category'] = 'Kategorie';
$locale['Personal'] = 'Osobní';
$locale['Show'] = 'Zobrazit';
$locale['Hide'] = 'Schovat';
$locale['All'] = 'Vše';
$locale['Filter'] = 'Filtr';
$locale['SQLFailed'] = 'Dotaz SQL selhal: %s';
$locale['InvalidLanguage'] = 'Byl zvolen chybný jazyk (%s).';
$locale['Actions'] = 'Akce';
$locale['Any'] = 'Jakýkoliv';
$locale['Text'] = 'Text';
$locale['Finished'] = 'Ukončen';
$locale['Edit'] = 'Upravit';
$locale['Delete'] = 'Smazat';
$locale['Created'] = 'Vytvořen';
$locale['Updated'] = 'Aktualizován';
$locale['Closed'] = 'Uzavřený';
$locale['Reopen'] = 'Otevřít';
$locale['Finish'] = 'Ukončit';
$locale['TaskFinished'] = 'Úkol %s byl ukončen.';
$locale['TaskReopened'] = 'Úkol %s byl otevřen.';
$locale['TaskDeleted'] = 'Úkol %s byl vymazán.';
$locale['CategoryDeleted'] = 'Kategorie %s byla vymazána.';
$locale['TaskChanged'] = 'Úkol %s byl změněn.';
$locale['CategoryChanged'] = 'Kategorie %s byla změněna.';
$locale['InvalidId']  = 'Chyné ID.';
$locale['Yes'] = 'Ano';
$locale['No'] = 'Ne';
$locale['Item'] = 'Položka';
$locale['OldestTask'] = 'Nejstarší úkol';
$locale['OldestOpenedTask'] = 'Nejstarší otevřený úkol';
$locale['TotalTaskCount'] = 'Celkem úkolů';
$locale['OpenedTaskCount'] = 'Otevřených úkolů';
$locale['OpenedTaskP0'] = 'Otevřených úkolů s nízkou prioritou';
$locale['OpenedTaskP1'] = 'Otevřených úkolů se střední prioritou';
$locale['OpenedTaskP2'] = 'Otevřených úkolů s vysokou prioritou';
$locale['AverageOpenedAge'] = 'Průměrné stáří otevřeného úkolu';
$locale['AverageCloseAge'] = 'Průměrné stáří úkolu při uzavření';
$locale['AverageAge'] = 'Průměrné stáří úkolu';
$locale['OldestOpenedTaskAge'] = 'Stáří nejdéle otevřeného úkolu';
$locale['OldestTaskAge'] = 'Stáří nejstaršího úkolu';
$locale['Days'] = 'dnů';
$locale['DeleteCategory'] = 'Chcete vymazat kategorii "%s"';
$locale['TasksInCategory'] = 'Počet úkolů v kategorii: %d';
$locale['NoTaskCategory'] = 'Nebyly nalezeny žádné úkoly v této kategorii.';
$locale['SelectDeleteTask'] = 'Co chcete udělat s úkoly ve vymazané kategorii?';
$locale['TargetCategory'] = 'Cílová kategorie';
$locale['MoveTo'] = 'Přesunout do jiné kategorie';

$locale['datefmt'] = '%d.%m.%Y, %H:%M';

$locale['DatabaseCreated'] = 'Databáze %s byla vytvořena.';
$locale['TableCreated'] = 'Tabulka %s byla vytvořena.';
$locale['TablesUpdated'] = 'Tabulky jsou v pořádku (případné úpravy jsou popsány výše), můžete se vrátit zpět na index.php.';
$locale['SettingsDbUpdated'] = 'Databáze nastavení byla aktualizována';
$locale['SettingsUpdated'] = 'Nastavení byla aktualizována';

$locale['SetLanguage'] = 'Jazyk';
$locale['SetStyle'] = 'Vzhled';
$locale['SetAddStay'] = 'Zůstat na přidávací stránce po přidání úkolu';
$locale['SetAddList'] = 'Zobrazit seznam úkolů na přidávací stránce';
$locale['Save'] = 'Uložit';
$locale['ConcurrecyError'] = 'Chyba konkuretního přístupu! Změny nebyly uloženy, protože někdo mezitím změnil záznam.';
$locale['TableNeedsUpdate'] = 'Tabulka %s potřebuje aktualizaci. Prosím aktualizujte ji, nebo použijte setup.php.';
$locale['TableUpdated'] = 'Tabulka %s aktualizována.';
?>
